==> wilmar-in-domain-0.0.86-sources.jar: com/xforceplus/wilmar/entity/InvoiceMain.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-06-22
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceMain implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceId;

  private String invoiceType;

  private String invoiceNo;

  private String invoiceCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerAddrTel;

  private String sellerAddress;

  private String sellerTel;

  private String sellerBankInfo;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddrTel;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserBankInfo;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private LocalDateTime paperDrewDate;

  private String remark;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotificationNo;

  private String sellerNo;

  private String purchaserNo;

  private String imageUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String bookkeepingStatus;

  private String identifyStatus;

  private String salesbillNo;

  private String invoiceAllocationStatus;

  private Long sellerId;

  private Long purchaserId;

  private String taxRate;

  private String tenantCode;

  private String specialInvoiceFlag;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserCode;

  private String sellerCode;

  private String invoiceSheet;

  private String imageId;

  private String invoiceUrl;

  private String systemSource;

  private String invoiceStatusType;

  private String deductionInvoiceUrl;

  private String postingDate;

  private String invoiceCategory;

  private Long redFlag;




        }

==> wilmar-in-domain-0.0.121-sources.jar: com/xforceplus/wilmar/entity/InvoiceMain.java <==
package com.xforceplus.wilmar.entity;

import java.math.BigDecimal;
import java.time.LocalDateTime;
import java.io.Serializable;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

/**
 * <p>
 * 
 * </p>
 *
 * @author wangzheng
 * @since 2020-07-12
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class InvoiceMain implements Serializable {

  private static final long serialVersionUID=1L;

  private String invoiceId;

  private String invoiceType;

  private String invoiceNo;

  private String invoiceCode;

  private String sellerTaxNo;

  private String sellerName;

  private String sellerAddrTel;

  private String sellerAddress;

  private String sellerTel;

  private String sellerBankInfo;

  private String sellerBankName;

  private String sellerBankAccount;

  private String purchaserTaxNo;

  private String purchaserName;

  private String purchaserAddrTel;

  private String purchaserAddress;

  private String purchaserTel;

  private String purchaserBankInfo;

  private String purchaserBankName;

  private String purchaserBankAccount;

  private BigDecimal amountWithoutTax;

  private BigDecimal taxAmount;

  private BigDecimal amountWithTax;

  private LocalDateTime paperDrewDate;

  private String remark;

  private String cashierName;

  private String checkerName;

  private String invoicerName;

  private String status;

  private String originInvoiceNo;

  private String originInvoiceCode;

  private String redNotificationNo;

  private String sellerNo;

  private String purchaserNo;

  private String imageUrl;

  private Long id;

  private Long tenantId;

  private LocalDateTime createTime;

  private LocalDateTime updateTime;

  private Long createUserId;

  private Long updateUserId;

  private String createUserName;

  private String updateUserName;

  private String deleteFlag;

  private String bookkeepingStatus;

  private String identifyStatus;

  private String salesbillNo;

  private String invoiceAllocationStatus;

  private Long sellerId;

  private Long purchaserId;

  private String taxRate;

  private String tenantCode;

  private String specialInvoiceFlag;

  private String orderNo;

  private String customerNo;

  private String currencyType;

  private String purchaserCode;

  private String sellerCode;

  private String invoiceSheet;

  private String imageId;

  private String invoiceUrl;

  private String systemSource;

  private String invoiceStatusType;

  private String deductionInvoiceUrl;

  private String postingDate;

  private String invoiceCategory;

  private Long redFlag;

  private String replaceInvoiceId;

  private String businessType;

  private String machineCode;

  private String checkCode;

  private String cipherText;

  private String authSyncStatus;

  private String authResponseTime;

  private String authRequestTime;

  private String authTaxPeriod;

  private String checkTime;

  private String authUse;

  private String calculateMark;

  private String imageToExist;




        }
